@@ -21,8 +21,8 @@ class MatterNode:
     """Matter node."""
 
     root_device_type_instance: MatterDeviceTypeInstance[device_types.RootNode]
-    bridge_device_type_instance: MatterDeviceTypeInstance[
-        device_types.Bridge
+    aggregator_device_type_instance: MatterDeviceTypeInstance[
+        device_types.Aggregator
     ] | None = None
     device_type_instances: list[MatterDeviceTypeInstance]
     node_devices: list[AbstractMatterNodeDevice]
@@ -35,7 +35,7 @@ class MatterNode:
 
         for endpoint_id, endpoint_info in node_info["attributes"].items():
             descriptor: all_clusters.Descriptor = endpoint_info["Descriptor"]
-            for device_info in descriptor.deviceList:
+            for device_info in descriptor.deviceTypeList:
                 device_type = device_types.ALL_TYPES.get(device_info.type)
 
                 if device_type is None:
@@ -49,8 +49,8 @@ class MatterNode:
                 )
                 if device_type is device_types.RootNode:
                     self.root_device_type_instance = instance
-                elif device_type is device_types.Bridge:
-                    self.bridge_device_type_instance = instance
+                elif device_type is device_types.Aggregator:
+                    self.aggregator_device_type_instance = instance
                 else:
                     device_type_instances.append(instance)
 
@@ -61,7 +61,7 @@ class MatterNode:
 
         self.node_devices = []
 
-        if self.bridge_device_type_instance:
+        if self.aggregator_device_type_instance:
             for instance in device_type_instances:
                 if instance.device_type == device_types.BridgedDevice:
                     self.node_devices.append(MatterBridgedNodeDevice(instance))
